.. _data:
************************************************
core (:mod:`MCEq.core`)
************************************************
.. currentmodule:: MCEq.core


This module contains the main program features. Instantiating :class:`MCEq.core.MCEqRun` will 
initialize the data structures and particle tables, create and fill the interaction and decay 
matrix and check if all information for the calculation of inclusive fluxes in the atmosphere is available.

Reference/API
=============
.. automodapi:: MCEq.core
  :inherited-members:
